<?php

namespace Opencart\Admin\Controller\Extension\Onwebchat\Module;
use \Opencart\System\Helper AS Helper;

class Onwebchat extends \Opencart\System\Engine\Controller {

	private string $extensionPath = 'extension/onwebchat/module/onwebchat';

	public function index(): void {
		$this->load->language($this->extensionPath);

		$this->document->setTitle($this->language->get('heading_title'));

		$data['breadcrumbs'] = [];

		$data['breadcrumbs'][] = [
			'text' => $this->language->get('text_home'),
			'href' => $this->url->link('common/dashboard', 'user_token=' . $this->session->data['user_token'])
		];

		$data['breadcrumbs'][] = [
			'text' => $this->language->get('text_extension'),
			'href' => $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=module')
		];

		if (!isset($this->request->get['module_id'])) {
			$data['breadcrumbs'][] = [
				'text' => $this->language->get('heading_title'),
				'href' => $this->url->link($this->extensionPath, 'user_token=' . $this->session->data['user_token'])
			];
		} else {
			$data['breadcrumbs'][] = [
				'text' => $this->language->get('heading_title'),
				'href' => $this->url->link($this->extensionPath, 'user_token=' . $this->session->data['user_token'] . '&module_id=' . $this->request->get['module_id'])
			];
		}

		if (!isset($this->request->get['module_id'])) {
			$data['save'] = $this->url->link($this->extensionPath . '|save', 'user_token=' . $this->session->data['user_token']);
		} else {
			$data['save'] = $this->url->link($this->extensionPath . '|save', 'user_token=' . $this->session->data['user_token'] . '&module_id=' . $this->request->get['module_id']);
		}

		$data['back'] = $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=module');

		$data['module_onwebchat_chat_id'] = $this->config->get('module_onwebchat_chat_id');
		$data['module_onwebchat_status'] = $this->config->get('module_onwebchat_status');
		
		$data['user_token'] = $this->session->data['user_token'];

		$data['header'] = $this->load->controller('common/header');
		$data['column_left'] = $this->load->controller('common/column_left');
		$data['footer'] = $this->load->controller('common/footer');

		$this->response->setOutput($this->load->view($this->extensionPath, $data));
	}

	public function save(): void {
		$this->load->language($this->extensionPath);

		$json = [];

		if (!$this->user->hasPermission('modify', $this->extensionPath)) {
			$json['error']['warning'] = $this->language->get('error_permission');
		}

		if (!$this->request->post['module_onwebchat_chat_id']) {
			$json['error']['onwebchatchatid'] = $this->language->get('error_onwebchat_code');
		}

		if (!$json) {
			$this->load->model('setting/setting');

			$this->model_setting_setting->editSetting('module_onwebchat', $this->request->post);

			$json['success'] = $this->language->get('text_success');
		}

		$this->response->addHeader('Content-Type: application/json');
		$this->response->setOutput(json_encode($json));
	}

	public function install(): void {
		// Add extension permissions
		$this->load->model('user/user_group');
		$this->model_user_user_group->addPermission($this->user->getGroupId(), 'access', $this->extensionPath);
		$this->model_user_user_group->addPermission($this->user->getGroupId(), 'modify', $this->extensionPath);
	}

	public function uninstall(): void {
		// Remove extension permissions
		$this->load->model('user/user_group');
		$this->model_user_user_group->removePermission($this->user->getGroupId(), 'access', $this->extensionPath);
		$this->model_user_user_group->removePermission($this->user->getGroupId(), 'modify', $this->extensionPath);
	}
}
